@@ -226,7 +226,7 @@ class Client:
             """
             url = '{}fileupdate/{}/{}/?sub_sheet={}'.format(self.base_url, provider_id, sheet_id, sub_sheet)
             headers = {'Authorization': 'Token {}'.format(self.api_token), 'Content-Type':'application/json'}
-            sheet = requests.post(url, headers=headers, data=df_to_json(data))
+            sheet = requests.post(url, headers=headers, data=df_to_json(data.fillna("")))
             if sheet.status_code == 200:
                 return(sheet.json())
             else:
@@ -267,7 +267,7 @@ class Client:
                 raise RuntimeError("folder_path cannot be set with sheet_type=sheet")
             url = '{}filecreate/{}/{}/?sub_sheet={}&sheet_type={}&folder_id={}'.format(self.base_url, provider_id, sheet_name, sub_sheet, sheet_type, folder_path)
             headers = {'Authorization': 'Token {}'.format(self.api_token), 'Content-Type':'application/json'}
-            sheet = requests.post(url, headers=headers, data=df_to_json(data))
+            sheet = requests.post(url, headers=headers, data=df_to_json(data.fillna("")))
             if sheet.status_code == 200:
                 return(sheet.json())
             else:
